==> gimp-1.3.18.tar.bz2: gimp-1.3.18/app/core/gimpitemundo.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_ITEM_UNDO_H__
#define __GIMP_ITEM_UNDO_H__


#include "gimpundo.h"


#define GIMP_TYPE_ITEM_UNDO            (gimp_item_undo_get_type ())
#define GIMP_ITEM_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_ITEM_UNDO, GimpItemUndo))
#define GIMP_ITEM_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_ITEM_UNDO, GimpItemUndoClass))
#define GIMP_IS_ITEM_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_ITEM_UNDO))
#define GIMP_IS_ITEM_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_ITEM_UNDO))
#define GIMP_ITEM_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_ITEM_UNDO, GimpItemUndoClass))


typedef struct _GimpItemUndoClass GimpItemUndoClass;

struct _GimpItemUndo
{
  GimpUndo  parent_instance;

  GimpItem *item;  /* the item this undo is for */
};

struct _GimpItemUndoClass
{
  GimpUndoClass  parent_class;
};


GType      gimp_item_undo_get_type (void) G_GNUC_CONST;

GimpUndo * gimp_item_undo_new      (GimpImage           *gimage,
                                    GimpItem            *item,
                                    GimpUndoType         undo_type,
                                    const gchar         *name,
                                    gpointer             data,
                                    gsize                size,
                                    gboolean             dirties_image,
                                    GimpUndoPopFunc      pop_func,
                                    GimpUndoFreeFunc     free_func);


#endif /* __GIMP_ITEM_UNDO_H__ */

==> gimp-2.0.2.tar.bz2: gimp-2.0.2/app/core/gimpitemundo.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_ITEM_UNDO_H__
#define __GIMP_ITEM_UNDO_H__


#include "gimpundo.h"


#define GIMP_TYPE_ITEM_UNDO            (gimp_item_undo_get_type ())
#define GIMP_ITEM_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_ITEM_UNDO, GimpItemUndo))
#define GIMP_ITEM_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_ITEM_UNDO, GimpItemUndoClass))
#define GIMP_IS_ITEM_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_ITEM_UNDO))
#define GIMP_IS_ITEM_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_ITEM_UNDO))
#define GIMP_ITEM_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_ITEM_UNDO, GimpItemUndoClass))


typedef struct _GimpItemUndoClass GimpItemUndoClass;

struct _GimpItemUndo
{
  GimpUndo  parent_instance;

  GimpItem *item;  /* the item this undo is for */
};

struct _GimpItemUndoClass
{
  GimpUndoClass  parent_class;
};


GType      gimp_item_undo_get_type (void) G_GNUC_CONST;

GimpUndo * gimp_item_undo_new      (GimpImage           *gimage,
                                    GimpItem            *item,
                                    GimpUndoType         undo_type,
                                    const gchar         *name,
                                    gpointer             data,
                                    gint64               size,
                                    gboolean             dirties_image,
                                    GimpUndoPopFunc      pop_func,
                                    GimpUndoFreeFunc     free_func);


#endif /* __GIMP_ITEM_UNDO_H__ */
